@@ -8,7 +8,8 @@ from . import models
 
 class AchievementForm(forms.ModelForm):
     name = forms.CharField(label='Goal name')
-    target = forms.IntegerField(min_value=models.TARGET_MIN, max_value=models.TARGET_MAX)
+    target = forms.IntegerField(min_value=models.TARGET_MIN, max_value=models.TARGET_MAX,
+        label='How many stars to achieve the goal?')
     next_url = forms.CharField(required=False, max_length=255, widget=forms.HiddenInput)
 
     class Meta:
@@ -22,7 +23,7 @@ class AchievementForm(forms.ModelForm):
     helper.layout = Layout(
         Fieldset(
             '',
-            Field('name', placeholder='What is the goal?'),
+            Field('name', placeholder='Set a new goal for your child'),
             Field('target', placeholder='00', maxlength='2')
         ),
         FormActions(
